==> react-molecule-progress-steps-1.1.0.tgz: package/lib/components/MoleculeProgressStep/index.js <==
import React, { Fragment } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
var BASE_CLASS = "sui-MoleculeProgressSteps";
var CLASS_STEPS = BASE_CLASS + "-path";
var CLASS_BAR = CLASS_STEPS + "-bar";
var CLASS_STEP = CLASS_STEPS + "-step";
var CLASS_STEP_NUMBER = CLASS_STEP + "-number";
var CLASS_STEP_ICON = CLASS_STEP + "-icon";
var CLASS_STEP_DESCRIPTION = CLASS_STEP + "-description";
/* status */

var CLASS_BAR_VISITED = CLASS_BAR + "--visited";
var CLASS_STEP_ACTIVE = CLASS_STEP + "--active";
var CLASS_STEP_VISITED = CLASS_STEP + "--visited";
var STATUSES = {
  VISITED: 'VISITED',
  NORMAL: 'NORMAL',
  ACTIVE: 'ACTIVE'
};

var isVisited = function isVisited(status) {
  return status === STATUSES.VISITED;
};

var isActive = function isActive(status) {
  return status === STATUSES.ACTIVE;
};

var getStatusClass = function getStatusClass(status) {
  if (isVisited(status)) return [CLASS_STEP_VISITED, CLASS_BAR_VISITED];
  if (isActive(status)) return [CLASS_STEP_ACTIVE, ''];
  return ['', ''];
};

var MoleculeProgressStep = function MoleculeProgressStep(_ref) {
  var status = _ref.status,
      icon = _ref.icon,
      label = _ref.label,
      numStep = _ref.numStep,
      lastStep = _ref.lastStep,
      compressed = _ref.compressed;

  var _getStatusClass = getStatusClass(status),
      CLASS_STEP_STATUS = _getStatusClass[0],
      CLASS_BAR_STATUS = _getStatusClass[1];

  var bar = React.createElement("hr", {
    className: cx(CLASS_BAR, CLASS_BAR_STATUS)
  });
  return React.createElement(Fragment, null, !compressed && React.createElement("div", {
    className: cx(CLASS_STEP, CLASS_STEP_STATUS)
  }, icon ? React.createElement("div", {
    className: CLASS_STEP_ICON
  }, icon) : React.createElement("p", {
    className: CLASS_STEP_NUMBER
  }, numStep), React.createElement("p", {
    className: CLASS_STEP_DESCRIPTION
  }, label)), !lastStep ? bar : compressed && bar);
};

export default MoleculeProgressStep;
export { STATUSES };

==> react-molecule-progress-steps-1.2.0.tgz: package/lib/components/MoleculeProgressStep/index.js <==
import React from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
var BASE_CLASS = "sui-MoleculeProgressSteps";
var CLASS_STEPS = BASE_CLASS + "-path";
var CLASS_BAR = CLASS_STEPS + "-bar";
var CLASS_STEP = CLASS_STEPS + "-step";
var CLASS_STEP_NUMBER = CLASS_STEP + "-number";
var CLASS_STEP_ICON = CLASS_STEP + "-icon";
var CLASS_STEP_DESCRIPTION = CLASS_STEP + "-description";
/* status */

var CLASS_BAR_VISITED = CLASS_BAR + "--visited";
var CLASS_STEP_ACTIVE = CLASS_STEP + "--active";
var CLASS_STEP_VISITED = CLASS_STEP + "--visited";
var STATUSES = {
  VISITED: 'VISITED',
  NORMAL: 'NORMAL',
  ACTIVE: 'ACTIVE'
};

var isVisited = function isVisited(status) {
  return status === STATUSES.VISITED;
};

var isActive = function isActive(status) {
  return status === STATUSES.ACTIVE;
};

var getStatusClass = function getStatusClass(status) {
  if (isVisited(status)) return [CLASS_STEP_VISITED, CLASS_BAR_VISITED];
  if (isActive(status)) return [CLASS_STEP_ACTIVE, ''];
  return ['', ''];
};

var MoleculeProgressStep = function MoleculeProgressStep(_ref) {
  var status = _ref.status,
      icon = _ref.icon,
      label = _ref.label,
      numStep = _ref.numStep,
      lastStep = _ref.lastStep,
      compressed = _ref.compressed;

  var _getStatusClass = getStatusClass(status),
      CLASS_STEP_STATUS = _getStatusClass[0],
      CLASS_BAR_STATUS = _getStatusClass[1];

  var bar = React.createElement("hr", {
    className: cx(CLASS_BAR, CLASS_BAR_STATUS)
  });
  return React.createElement(React.Fragment, null, !compressed && React.createElement("div", {
    className: cx(CLASS_STEP, CLASS_STEP_STATUS)
  }, icon ? React.createElement("div", {
    className: CLASS_STEP_ICON
  }, icon) : React.createElement("p", {
    className: CLASS_STEP_NUMBER
  }, numStep), React.createElement("p", {
    className: CLASS_STEP_DESCRIPTION
  }, label)), !lastStep ? bar : compressed && bar);
};

export default MoleculeProgressStep;
export { STATUSES };
